----------------------------------
--      Locals                  --
----------------------------------

local name = "Timers: Molten Core"
local L = AceLibrary("AceLocale-2.2"):new("BigWigs"..name)
-- packNumber is basically just a counter for the mob types, so that when one
-- mob of a type dies, its counter is increased by 1 so that we have some way of
-- telling mobs apart. It will never reset outside of a reload UI or relog.
local packNumber = nil

-- We throttle the deaths of each mob type by 60 seconds by default, so that if
-- 2 mobs of the same type die within 60 seconds of eachother, you'll only get 1
-- respawn timer for them, that starts at the kill of the first one. This was
-- added mostly for core hound packs in MC.
local deathThrottle = nil

----------------------------------
--      Localization            --
----------------------------------
L:RegisterTranslations("enUS", function() return {
	cmd = "TimersMC",
	Bars_cmd = "bars",
	Bars_name= "Bars",
	Bars_desc= "Toggles showing bars for respawn times.",
	Messages_cmd ="messages",
	Messages_name = "Messages",
	Messages_desc = "Toggles showing messages for respawn times.",

	

	["%s %d respawns in %d sec"] = true,
	["%s %d respawned!"] = true,
	["Respawn: %s %d"] = true,

	-- Molten Core Triggers
	["Molten Giant"] = true,
	["Ancient Core Hound"] = true,
	["Lava Annihilator"] = true,
	["Lava Surger"] = true,
	["Firelord"] = true,
	["Firewalker"] = true, -- Lava Pack
	["%s collapses and begins to smolder."] = true, -- Hound Pack, emote.
	-- Molten Core Messages
	["Corehound"] = true,
	["Annihilator"] = true,
	["Surger"] = true,
	-- Firelord == Firelord.
	["Lavapack"] = true,
	["Houndpack"] = true,

} end )
L:RegisterTranslations("deDE", function() return {
	cmd = "TimersMC",
	Bars_cmd = "bars",
	Bars_name= "Balken",
	Bars_desc= "Zeige Balken",
	Messages_cmd ="messages",
	Messages_name = "Warnungen",
	Messages_desc = "Sende Warnungen",
	


--	["Respawn timer bars and warnings for trash mobs."] = "Respawn Timerbalken und Warnungen f\195\188r Trashmobs",
		
	["%s %d respawns in %d sec"] = "%s %d respawnt in %d Sekunden",
	["%s %d respawned!"] = "%s %s respawnt",
	["Respawn: %s %d"] = "Respawn: %s %d",

	-- Molten Core Triggers
	["Molten Giant"] = "Molten Giant", -- Need translated
	["Ancient Core Hound"] = "Uralter Kernhund",
	["Lava Annihilator"] = "Lavavernichter",
	["Lava Surger"] = "Lavawoger",
	["Firelord"] = "Feuerlord",
	["Firewalker"] = "Feuerg\195\164nger", -- Lava Pack
	["%s collapses and begins to smolder."] = "%s bricht zusammen und beginnt zu glimmen.", -- Hound Pack, emote.
	-- Molten Core Messages
	["Corehound"] =  "Kernhund",
	["Annihilator"] = "Vernichter",
	["Surger"] = "Woger",
	-- Firelord == Firelord.
	["Lavapack"] = "Lavapack",
	["Houndpack"] = "Kernhundpack",


} end )

-- The death table and emote table are basically the meat of this addon. The
-- first string is what we search for in the responding chat event, the table
-- that is attached to it is: 1. respawn time in seconds, 2. the bar text and
-- message text for the respawn timer, 3. optional icon path for this timer.
local deathTable = {
	-- MC
	[L["Ancient Core Hound"]] = {1080, L["Corehound"], nil},
	[L["Lava Annihilator"]]   = {7200, L["Annihilator"], nil},
	[L["Lava Surger"]]        = {1620, L["Surger"], nil},
	[L["Firelord"]]           = {7200, L["Firelord"], nil},
	[L["Firewalker"]]         = {7200, L["Lavapack"], nil},
}

local emoteTable = {
	-- MC
	[L["%s collapses and begins to smolder."]] = {3600, L["Houndpack"], nil},
}

----------------------------------
--  Addon Declaration           --
----------------------------------

BigWigsMCTimers = BigWigs:NewModule(name)
BigWigsMCTimers.defaultDB = {
	bars = true,
	messages = true,
}
BigWigsMCTimers.synctoken = name
BigWigsMCTimers.zonename = AceLibrary("Babble-Zone-2.2")["Molten Core"]
BigWigsMCTimers.enabletrigger = { L["Molten Giant"], L["Firelord"], L["Lava Annihilator"], L["Ancient Core Hound"] }
BigWigsMCTimers.toggleoptions = { "Bars","Messages" }
BigWigsMCTimers.revision = tonumber(string.sub("$Revision: 16666 $", 12, -3))

----------------------------------
--      Initialization          --
----------------------------------

function BigWigsMCTimers:OnEnable()
	packNumber = {}
	deathThrottle = {}
	self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH")
	self:RegisterEvent("CHAT_MSG_MONSTER_EMOTE")
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	
end

----------------------------------
--      Events                  --
----------------------------------

-- Basically just loop the corresponding mob table and check if the event
-- arguments (death or emote) matches anything we've registered. If so, trigger
-- a respawn timer.

function BigWigsMCTimers:CHAT_MSG_COMBAT_HOSTILE_DEATH(msg)
	for key, table in pairs(deathTable) do
		if msg == string.format(UNITDIESOTHER, key) then
			self:StartRespawnTimer(table[2], table[1], table[3])
			break
		end
	end
end

function BigWigsMCTimers:CHAT_MSG_MONSTER_EMOTE(msg)
	for key, table in pairs(emoteTable) do
		if msg == key then
			self:StartRespawnTimer(table[2], table[1], table[3])
			break
		end
	end
end
function BigWigsMCTimers:ZONE_CHANGED_NEW_AREA()
if GetRealZoneText() == AceLibrary("Babble-Zone-2.2")["Molten Core"] then
else
self.core:ToggleModuleActive(self, false)
end
end

----------------------------------
--    Utility                   --
----------------------------------

function BigWigsMCTimers:StartRespawnTimer(message, timer, icon, throttle)
	timer = tonumber(timer)
	if timer == nil then return end

	-- Throttle deaths by 60 seconds.
	if deathThrottle[message] and (deathThrottle[message] + 60) > GetTime() then return end
	deathThrottle[message] = GetTime()

	-- Increment the pack counter after all arguments are checked and we're sure
	-- to start a new respawn timer.
	if not packNumber[message] then packNumber[message] = 0 end
	local nextPack = packNumber[message] + 1
	packNumber[message] = nextPack

	-- Make sure the user wants respawn messages.
	if self.db.profile.messages then
		self:ScheduleEvent("bwrt"..nextPack.."10secwarn", "BigWigs_Message", timer - 10, string.format(L["%s %d respawns in %d sec"], message, nextPack, 10), "Yellow")
		self:ScheduleEvent("bwrt"..nextPack.."respawned", "BigWigs_Message", timer, string.format(L["%s %d respawned!"], message, nextPack), "Orange")
	end

	-- Make sure the user wants respawn timer bars.
	if self.db.profile.bars then
		-- Default icon.
		if not icon then icon = "Interface\\Icons\\INV_Misc_Head_Dragon_01" end
		local text = string.format(L["Respawn: %s %d"], message, nextPack)
		self:TriggerEvent("BigWigs_StartBar", self, text, timer, icon)
		self:SetCandyBarOnClick("BigWigsBar "..text, function()
			if IsControlKeyDown() then
				self:TriggerEvent("BigWigs_StopBar", self, text)
				self:CancelScheduledEvent("bwrt"..nextPack.."10secwarn")
				self:CancelScheduledEvent("bwrt"..nextPack.."respawned")
			end
		end)
	end
end

